==> wallaroo-2023.3.0b2-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/api/pipelines/list_publishes_for_pipeline.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.list_request import ListRequest
from ...models.list_response import ListResponse
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ListRequest,

) -> Dict[str, Any]:
    url = "{}/v1/api/pipelines/list_publishes_for_pipeline".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ListResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ListResponse.from_dict(response.json())



        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[ListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ListRequest,

) -> Response[ListResponse]:
    """ Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

     Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

    Args:
        json_body (ListRequest): Request to list published pipelines.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ListResponse]
     """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: Client,
    json_body: ListRequest,

) -> Optional[ListResponse]:
    """ Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

     Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

    Args:
        json_body (ListRequest): Request to list published pipelines.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ListResponse
     """


    return sync_detailed(
        client=client,
json_body=json_body,

    ).parsed

async def asyncio_detailed(
    *,
    client: Client,
    json_body: ListRequest,

) -> Response[ListResponse]:
    """ Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

     Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

    Args:
        json_body (ListRequest): Request to list published pipelines.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ListResponse]
     """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: Client,
    json_body: ListRequest,

) -> Optional[ListResponse]:
    """ Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

     Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

    Args:
        json_body (ListRequest): Request to list published pipelines.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ListResponse
     """


    return (await asyncio_detailed(
        client=client,
json_body=json_body,

    )).parsed

==> wallaroo-2023.4.0b0-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/api/pipelines/list_publishes_for_pipeline.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.list_request import ListRequest
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ListRequest,

) -> Dict[str, Any]:
    url = "{}/v1/api/pipelines/list_publishes_for_pipeline".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Any]:
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ListRequest,

) -> Response[Any]:
    """ Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

     Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

    Args:
        json_body (ListRequest): Request to list published pipelines.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
     """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: ListRequest,

) -> Response[Any]:
    """ Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

     Lists the publishes for a Pipeline. This aggregates publishes for all versions of that Pipeline.

    Args:
        json_body (ListRequest): Request to list published pipelines.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
     """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(client=client, response=response)
